.. |date| date::

******************
Welcome to Yangson
******************

:Author: Ladislav Lhotka <lhotka@nic.cz>
:Date: |date|

*Yangson* is a Python 3 library for working with `JSON encoded`_
configuration and state data modelled using the YANG_
data modelling language.

**Requirements:** Python 3.5 or higher, PyXB_

**License**: LGPLv3

**Installation**::

    python -m pip install yangson


Development
===========

* Instructions_ for installing the development environment.

Links
=====

* `Git repository`_
* `Documentation`_

.. _JSON encoded: https://tools.ietf.org/html/rfc7951
.. _YANG: https://tools.ietf.org/html/rfc7950
.. _PyXB: https://pypi.python.org/pypi/PyXB
.. _Instructions: https://github.com/CZ-NIC/yangson/wiki/devinstall
.. _Git repository: https://github.com/CZ-NIC/yangson
.. _Documentation: http://yangson.readthedocs.io
